@@ -6,7 +6,12 @@ use warnings;
 use lib qw|lib/ t/lib/ t/lib/Gearman/ t/brokers/|;
 
 use Moose;
-with 'FailsOnceWillRetryWorker', 'Gearman::TestWorker' => { -excludes => [ 'configuration', 'retries' ], };
+with 'Gearman::TestWorker', 'FailsOnceWillRetryWorker' => { -excludes => [ 'configuration', 'retries' ], };
+
+sub retries()
+{
+    return 3;
+}
 
 no Moose;
 
